<?php
/**
 * Activities Section options
 *
 * @package Theme Palace
 * @subpackage Tourable Pro
 * @since Tourable Pro 1.0.0
 */

// Add Activities section
$wp_customize->add_section( 'tourable_pro_activities_section', array(
	'title'             => esc_html__( 'Activities','tourable-pro' ),
	'description'       => esc_html__( 'Activities Section options.', 'tourable-pro' ),
	'panel'             => 'tourable_pro_front_page_panel',
) );

// Activities content enable control and setting
$wp_customize->add_setting( 'tourable_pro_theme_options[activities_section_enable]', array(
	'default'			=> 	$options['activities_section_enable'],
	'sanitize_callback' => 'tourable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tourable_Pro_Switch_Control( $wp_customize, 'tourable_pro_theme_options[activities_section_enable]', array(
	'label'             => esc_html__( 'Activities Section Enable', 'tourable-pro' ),
	'section'           => 'tourable_pro_activities_section',
	'on_off_label' 		=> tourable_pro_switch_options(),
) ) );

// activities title setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[activities_title]', array(
	'default'			=> $options['activities_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[activities_title]', array(
	'label'           	=> esc_html__( 'Title', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_activities_section',
	'active_callback' 	=> 'tourable_pro_is_activities_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tourable_pro_theme_options[activities_title]', array(
		'selector'            => '#discover-places .section-header h2.section-title',
		'settings'            => 'tourable_pro_theme_options[activities_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tourable_pro_activities_title_partial',
    ) );
}

// activities sub title setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[activities_sub_title]', array(
	'default'			=> $options['activities_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[activities_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_activities_section',
	'active_callback' 	=> 'tourable_pro_is_activities_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tourable_pro_theme_options[activities_sub_title]', array(
		'selector'            => '#discover-places .section-header span.section-subtitle',
		'settings'            => 'tourable_pro_theme_options[activities_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tourable_pro_activities_sub_title_partial',
    ) );
}

// activities suffix setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[activities_suffix]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['activities_suffix'],
) );

$wp_customize->add_control( 'tourable_pro_theme_options[activities_suffix]', array(
	'label'           	=> esc_html__( 'Suffix After Trip Count', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_activities_section',
	'active_callback' 	=> 'tourable_pro_is_activities_section_enable',
	'type'				=> 'text',
) );

// Activities count control and setting
$wp_customize->add_setting( 'tourable_pro_theme_options[activities_count]', array(
	'default'          	=> $options['activities_count'],
	'sanitize_callback' => 'tourable_pro_sanitize_number_range',
	'validate_callback' => 'tourable_pro_validate_activities_count',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[activities_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'tourable-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'tourable-pro' ),
	'section'           => 'tourable_pro_activities_section',
	'active_callback'   => 'tourable_pro_is_activities_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 9,
		'style' => 'width: 100px;'
		),
) );

// Activities content type control and setting
$wp_customize->add_setting( 'tourable_pro_theme_options[activities_content_type]', array(
	'default'          	=> $options['activities_content_type'],
	'sanitize_callback' => 'tourable_pro_sanitize_select',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[activities_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tourable-pro' ),
	'section'           => 'tourable_pro_activities_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tourable_pro_is_activities_section_enable',
	'choices'			=> tourable_pro_activities_content_type(),
) );

for ( $i = 1; $i <= $options['activities_count']; $i++ ) :
	// banner image setting and control.
	$wp_customize->add_setting( 'tourable_pro_theme_options[activities_background_image_' . $i . ']', array(
		'sanitize_callback' => 'tourable_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tourable_pro_theme_options[activities_background_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'tourable-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'tourable-pro' ), 500, 500 ),
			'section'     		=> 'tourable_pro_activities_section',
			'active_callback'	=> 'tourable_pro_is_activities_section_enable',
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'tourable_pro_theme_options[activities_content_category_' . $i . ']', array(
		'sanitize_callback' => 'tourable_pro_sanitize_single_category',
	) ) ;

	$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[activities_content_category_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Category %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_activities_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'tourable_pro_is_activities_section_content_category_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'tourable_pro_theme_options[activities_content_trip_types_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[activities_content_trip_types_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Trip Types %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_activities_section',
		'taxonomy'			=> 'itinerary_types',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'tourable_pro_is_activities_section_content_trip_types_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'tourable_pro_theme_options[activities_content_activity_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[activities_content_activity_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Activities %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_activities_section',
		'taxonomy'			=> 'activity',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'tourable_pro_is_activities_section_content_activity_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'tourable_pro_theme_options[activities_content_destination_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[activities_content_destination_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Destination %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_activities_section',
		'taxonomy'			=> 'travel_locations',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'tourable_pro_is_activities_section_content_destination_enable'
	) ) );

	// activities hr setting and control
	$wp_customize->add_setting( 'tourable_pro_theme_options[activities_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Tourable_Pro_Customize_Horizontal_Line( $wp_customize, 'tourable_pro_theme_options[activities_hr_'. $i .']',
		array(
			'section'         => 'tourable_pro_activities_section',
			'active_callback' => 'tourable_pro_is_activities_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// activities title setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[activities_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['activities_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[activities_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_activities_section',
	'active_callback' 	=> 'tourable_pro_is_activities_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tourable_pro_theme_options[activities_btn_title]', array(
		'selector'            => '#activities .read-more a.btn',
		'settings'            => 'tourable_pro_theme_options[activities_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tourable_pro_activities_btn_title_partial',
    ) );
}

// activities btn url setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[activities_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[activities_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_activities_section',
	'active_callback' 	=> 'tourable_pro_is_activities_section_enable',
	'type'				=> 'url',
) );