<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Tourable Pro
 * @since Tourable Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'tourable_pro_service_section', array(
	'title'             => esc_html__( 'Services','tourable-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'tourable-pro' ),
	'panel'             => 'tourable_pro_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'tourable_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'tourable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tourable_Pro_Switch_Control( $wp_customize, 'tourable_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'tourable-pro' ),
	'section'           => 'tourable_pro_service_section',
	'on_off_label' 		=> tourable_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'tourable_pro_theme_options[service_section_icon_enable]', array(
	'default'			=> 	$options['service_section_icon_enable'],
	'sanitize_callback' => 'tourable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tourable_Pro_Switch_Control( $wp_customize, 'tourable_pro_theme_options[service_section_icon_enable]', array(
	'label'             => esc_html__( 'Service Section Icon Enable', 'tourable-pro' ),
	'section'           => 'tourable_pro_service_section',
	'on_off_label' 		=> tourable_pro_switch_options(),
	'active_callback'	=> 'tourable_pro_is_service_section_enable'
) ) );

// service btn label setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[service_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_btn_label'],
	'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[service_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_service_section',
	'active_callback' 	=> 'tourable_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Service content type control and setting
$wp_customize->add_setting( 'tourable_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'tourable_pro_sanitize_select',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tourable-pro' ),
	'section'           => 'tourable_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tourable_pro_is_service_section_enable',
	'choices'			=>tourable_pro_service_content_type(),
) );

for ( $i = 1; $i <= 3; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'tourable_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Tourable_Pro_Icon_Picker( $wp_customize, 'tourable_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_service_section',
		'active_callback'	=> 'tourable_pro_is_service_section_icon_enable'
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'tourable_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tourable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tourable_Pro_Dropdown_Chooser( $wp_customize, 'tourable_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_service_section',
		'choices'			=> tourable_pro_page_choices(),
		'active_callback'	=> 'tourable_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'tourable_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tourable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tourable_Pro_Dropdown_Chooser( $wp_customize, 'tourable_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_service_section',
		'choices'			=> tourable_pro_post_choices(),
		'active_callback'	=> 'tourable_pro_is_service_section_content_post_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'tourable_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_setting( 'tourable_pro_theme_options[service_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'tourable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tourable_Pro_Dropdown_Chooser( $wp_customize, 'tourable_pro_theme_options[service_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_service_section',
		'choices'			=> tourable_pro_trip_choices(),
		'active_callback'	=> 'tourable_pro_is_service_section_content_trip_enable',
	) ) );

	$wp_customize->add_control( new Tourable_Pro_Customize_Horizontal_Line( $wp_customize, 'tourable_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'tourable_pro_service_section',
			'active_callback' => 'tourable_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tourable_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'tourable_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tourable-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tourable-pro' ),
	'section'           => 'tourable_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tourable_pro_is_service_section_content_category_enable'
) ) );



$wp_customize->add_setting(  'tourable_pro_theme_options[service_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[service_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'tourable-pro' ),
	'section'           => 'tourable_pro_service_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tourable_pro_is_service_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tourable_pro_theme_options[service_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[service_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'tourable-pro' ),
	'section'           => 'tourable_pro_service_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tourable_pro_is_service_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tourable_pro_theme_options[service_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[service_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'tourable-pro' ),
	'section'           => 'tourable_pro_service_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tourable_pro_is_service_section_content_destination_enable'
) ) );